/* ISC license. */

#include <skalibs/textclient.h>

textclient const textclient_zero = TEXTCLIENT_ZERO ;
